#!/usr/bin/env node

  'use strict';
  const scanner = require('sonarqube-scanner').default;
  const env = process.env;

  try {
    let projectKey = `${env.BITBUCKET_REPO_OWNER}_${env.BITBUCKET_PROJECT_KEY}_${env.BITBUCKET_REPO_SLUG}`;

    let args = process.argv.slice(2);
    let langIndex = args.indexOf('-lang');
    let sonarUrlIndex = args.indexOf('-sonarurl');
    let pipelineTokenIndex = args.indexOf('-token');
    let sourcesIndex = args.indexOf('-sources');
    // Parse input
    let lang = args[langIndex + 1];
    let sonarUrl = args[sonarUrlIndex + 1];
    let pipelineToken = args[pipelineTokenIndex + 1];
    let sourcesToken;
    if( sourcesIndex > -1) {
      sourcesToken = args[sourcesIndex + 1];
    }
    else {
      sourcesToken = undefined;
    }


    let serverUrl = sonarUrl;
    let token = pipelineToken;

    if (!serverUrl || !token || !projectKey) {
      throw Error('Could not find SonarQube url, token and project key');
    }

    let options = {
      'sonar.projectKey': projectKey,
    }
    if (sourcesToken) {
      options['sonar.sources'] = sourcesToken;
    }

    if (lang.toLowerCase() === 'ts' || lang.toLowerCase() === 'typescript') {
      options['sonar.typescript.lcov.reportPaths'] = 'coverage/lcov.info';
    } else {
      options['sonar.tests'] = 'coverage/lcov.info';
    }

    scanner({
      serverUrl,
      token,
      options
    }, (err, data) => {
      console.log({message: 'Unexpected Error', error: err, data});
    });
  } catch (error) {
    console.log(error);
    if(error?.message?.contains("The folder 'src' does not exist for")) {
      console.log("supply parameter 'sources' with the value of the foldername where your functions reside");
    }
  }
